CustomData

Trait CustomData 

pub trait CustomData {
    // Required methods
    unsafe fn ptr(&self) -> *const u8;
    unsafe fn len(&self) -> usize;
}
Encapsulates custom data that can be wrapped.

Required Methods

unsafe fn ptr(&self) -> *const u8

Returns a pointer to the start of the custom data. This pointer must not change during the lifespan of this CustomData.

unsafe fn len(&self) -> usize

Returns the length of this custom data. This value must not change during the lifespan of this CustomData.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors