pub struct CGEventTap<'tap_life> { /* private fields */ }Expand description
use core_foundation::runloop::{kCFRunLoopCommonModes, CFRunLoop};
use core_graphics::event::{CGEventTap, CGEventTapLocation, CGEventTapPlacement, CGEventTapOptions, CGEventType, CallbackResult};
let current = CFRunLoop::get_current();
CGEventTap::with_enabled(
CGEventTapLocation::HID,
CGEventTapPlacement::HeadInsertEventTap,
CGEventTapOptions::Default,
vec![CGEventType::MouseMoved],
|_proxy, _type, event| {
println!("{:?}", event.location());
CallbackResult::Keep
},
|| CFRunLoop::run_current(),
).expect("Failed to install event tap");Implementations
Sourceimpl CGEventTap<'static>
impl CGEventTap<'static>
pub fn new<F: Fn(CGEventTapProxy, CGEventType, &CGEvent) -> CallbackResult + Send + 'static>( tap: CGEventTapLocation, place: CGEventTapPlacement, options: CGEventTapOptions, events_of_interest: Vec<CGEventType>, callback: F, ) -> Result<Self, ()>
Sourceimpl<'tap_life> CGEventTap<'tap_life>
impl<'tap_life> CGEventTap<'tap_life>
Sourcepub fn with_enabled<R>(
tap: CGEventTapLocation,
place: CGEventTapPlacement,
options: CGEventTapOptions,
events_of_interest: Vec<CGEventType>,
callback: impl Fn(CGEventTapProxy, CGEventType, &CGEvent) -> CallbackResult + 'tap_life,
with_fn: impl FnOnce() -> R,
) -> Result<R, ()>
pub fn with_enabled<R>( tap: CGEventTapLocation, place: CGEventTapPlacement, options: CGEventTapOptions, events_of_interest: Vec<CGEventType>, callback: impl Fn(CGEventTapProxy, CGEventType, &CGEvent) -> CallbackResult + 'tap_life, with_fn: impl FnOnce() -> R, ) -> Result<R, ()>
Configures an event tap with the supplied options and callback, then
calls with_fn.
Note that the current thread run loop must run within with_fn for the
tap to process events. The tap is destroyed when with_fn returns.
Sourcepub unsafe fn new_unchecked(
tap: CGEventTapLocation,
place: CGEventTapPlacement,
options: CGEventTapOptions,
events_of_interest: Vec<CGEventType>,
callback: impl Fn(CGEventTapProxy, CGEventType, &CGEvent) -> CallbackResult + 'tap_life,
) -> Result<Self, ()>
pub unsafe fn new_unchecked( tap: CGEventTapLocation, place: CGEventTapPlacement, options: CGEventTapOptions, events_of_interest: Vec<CGEventType>, callback: impl Fn(CGEventTapProxy, CGEventType, &CGEvent) -> CallbackResult + 'tap_life, ) -> Result<Self, ()>
Caller is responsible for ensuring that this object is dropped before
'tap_life expires. Either state captured by callback must be safe to
send across threads, or the tap must only be installed on the current
thread’s run loop.
pub fn mach_port(&self) -> &CFMachPort
pub fn enable(&self)